General Search Results-Summary -- Web of Science v4.31

General Search Results--Summary

Topic=troublesome; DocType=All document types; Language=All languages; Databases=SCI-EXPANDED; Timespan=All Years; (sorted by latest date)

| Page 1 (Articles 1 -- 10): |

|  |  | [ 1 | | 2 | | 3 | | 4 | | 5 | | 6 | | 7 | | 8 | | 9 | | 10 ]

Use the checkboxes to add individual articles to the Marked List. Be sure to click SUBMIT MARKS button before leaving page.

Jeppsson U, Alex J, Pons MN, et al.
  Status and future trends of ICA in wastewater treatment - a European perspective
  WATER SCI TECHNOL 45 (4-5): 485-494 2002
Gregory PL, Biswas AC, Batt ME
  Musculoskeletal problems of the chest wall in athletes
  SPORTS MED 32 (4): 235-250 2002
Chang DW, Hussussian C, Lewin JS, et al.
  Analysis of pharyngocutaneous fistula following free jejunal transfer for total laryngopharyngectomy
  PLAST RECONSTR SURG 109 (5): 1522-1527 APR 15 2002

| Page 1 (Articles 1 -- 10): |

|  |  | [ 1 | | 2 | | 3 | | 4 | | 5 | | 6 | | 7 | | 8 | | 9 | | 10 ]

1783 of 16635816 documents matched the query. (500 shown)

Acceptable Use Policy

Copyright © 2002 Institute for Scientific Information